@@ -1,5 +1,7 @@
+set.seed(123) # here just to make random sampling reproducible
+
 visualize <- FALSE # TRUE for manual tests with visualization of results
-require(fitdistrplus)
+require("fitdistrplus")
 
 myoptimize <- function(fn,par,ui,ci,...){
   res <- constrOptim(f=fn,theta=par,method="Nelder-Mead",ui=ui,ci=ci, ...)
@@ -19,8 +21,6 @@ fitdist(x, "exp", lower= 2, optim.method="L-BFGS-B")
 
 if(visualize) {  # check ERROR on aarch64-apple-darwin20.4.0 (64-bit) (2021/05/12)
   x <- rbeta(100, pi, 1/pi)
-
-    set.seed(1234)
   fitdist(x, "beta")
   
   #binding example 
@@ -30,7 +30,7 @@ if(visualize) {  # check ERROR on aarch64-apple-darwin20.4.0 (64-bit) (2021/05/1
 
 
 #true example
-library(GeneralizedHyperbolic)
+require("GeneralizedHyperbolic")
 args(dnig)
 
 
